{% extends base_template %}

{% load i18n %}

{% block ui_title %}{% trans "Delete confirmation" %}{% endblock %}

{% block content %}
    <p>{{ confirmation_text }}</p>

    <h2>{% trans "Summary" %}</h2>
    <ul>
        {% for model_name, object_count in deleted_model_count.items %}
        <li>{{ model_name|capfirst }}: {{ object_count }}</li>
        {% endfor %}
    </ul>
    <h2>{% trans "Objects" %}</h2>
    <ul>{{ deleted_objects|unordered_list }}</ul>

    <form method="post" action=".">{% csrf_token %}
        <button  type="submit">{% trans 'Delete' %}</button>
        <a href="{{ cancel_url }}">{% trans 'Cancel' %}</a>
    </form>
{% endblock %}
