table {
    border-collapse: collapse;
    border: 1px solid gray;
    width: 100%;
}

table th, table td {
    border: 1px solid gray;
    padding: 0.15em 0.5em;
}

a, a:visited {
    color: #607080;
}

#navbar-main {
    display: flex;
    background: #eee;
    padding: 0.5em;
}

#navbar-main > .navbar-header {
    flex: 1 1 auto;
}

#navbar-main > #main-navigation {
    flex: 1;
    text-align: right;
}

#main-navigation li {
    display: inline-block;
}

#body {
    display: flex;
}

#content {
    padding: 1em;
}

.breadcrumb ol {
    padding: 0;
    margin-top: 0;
    border: 1px solid rgba(0,0,0,0.1);
    border-radius: 0.5em;
    background-color: '#fafafa';
}

.breadcrumb li {
    list-style-type: none;
    display: inline-block;
}

.breadcrumb li:before {
    content: '\f101  '; /* fa-angle-double-right */
    font-family: "Font Awesome 5 Free";
    display: inline-block;
    font-weight: 900;
    color: gray;
}

.breadcrumb li:first-child:before {
    content: '';
}

#logo {
  width: 100px;
  height: auto;
}

#content {
    flex: 4;
}

#sidebar {
    background: #eee;
    padding: 1em 0.5em 0;
}

#sidebar ul {
    margin-top: 0;
    padding: 0.5em;
    border: 1px solid rgba(0,0,0,0.1);
    border-radius: 0.5em;
    list-style-type: none;
    background-color: #fafafa;
}

ul.actions {
    list-style-type: none;
    padding: 0;
}

ul.actions li {
    display: inline-block;
    padding: 0.25em 0.25em;
}

.header .header-info {
  font-size: 18px;
  font-weight: 400;
}

.inline {
     display: inline-block;
 }

.form-group {
     position: relative;
     margin-bottom: 0.5em;
 }

.form-group label {
     display: block;
 }

.form-control {
  border: 1px solid #ccc;
  box-shadow: inset 0 1px 1px rgba(0,0,0,.075);
  width: 100%;
}

.checkbox .form-control {
    min-width: auto;
    width: auto;
}

.checkbox label {
    padding-right: 1em;
}

.errorlist {
  display: block;;
  margin: 0;
  padding: 0;
  list-style: none;
  color: #B43431;
}

.add-another {
  position: absolute;
  left: 100%;
  top: 32px;
}

textarea {
    width: 100%;
}

.form {
  position: relative;
  margin-bottom: 2rem;
}

.form-inline {
    border: 1px solid gray;
    margin-top: 0.5em;
    padding: 0.25em;
}

.form-inline .form-group {
    vertical-align: top;
    display: inline-block;
    margin-bottom: 0;
}

.form-inline .form-control {
    min-width: 15em;
}

.form-inline .form-control.select2 {
    display: inline-block;
}

.form-inline .form-group ul {
    display: inline-block;
    padding: 0;
}

.form-inline .form-group li {
    list-style-type: none;
    display: inline-block;
    margin-left: 0.5em;
}

.filter-form .form-group label {
    display: inline-block;
}

label {
    font-weight: normal;
}

.required label {
    font-weight: bold;
}

#login {
    background: #eee;
}


#login form {
    border: 1px solid gray;
    border-radius: 0.5em;
    background: #fff;
    margin: 2em auto;
    width: 20em;
    padding: 1em;
}       
